@@ -1,61 +1,78 @@
 #' Print a dfm object
 #'
-#' Print methods for document-feature matrices
-#' @name print.dfm
-#' @keywords internal dfm
-NULL
-
-#' @param x the dfm to be printed
-#' @param show.values print the dfm values; if called explicitly this will print
-#'   all values.
-#' @param show.settings print the settings used to create the dfm. See 
-#'   \link{settings}.
-#' @param show.summary print a brief summary indicating the number of documents 
-#'   and features
-#' @param ndoc max number of documents to print; default is from the
-#'   \code{print_dfm_max_ndoc} setting of \code{\link{quanteda_options}}
-#' @param nfeat max number of features to print; default is from the
-#'   \code{print_dfm_max_nfeat} setting of \code{\link{quanteda_options}}
-#' @param ... further arguments passed to \code{Matrix::printSpMatrix2}
-#' @seealso \code{\link{quanteda_options}}
+#' @rdname print-quanteda
+#' @param max_nfeat max number of features to print; default is from the
+#'   `print_dfm_max_nfeat` setting of [quanteda_options()]
 #' @export
-#' @rdname print.dfm
 #' @keywords dfm
 setMethod("print", signature(x = "dfm"), 
-          function(x, show.values = NULL, show.settings = FALSE, 
-                   show.summary = TRUE, 
-                   ndoc = quanteda_options("print_dfm_max_ndoc"), 
-                   nfeat = quanteda_options("print_dfm_max_nfeat"), ...) {
-              if (show.summary) {
+          function(x, 
+                   max_ndoc = quanteda_options("print_dfm_max_ndoc"), 
+                   max_nfeat = quanteda_options("print_dfm_max_nfeat"), 
+                   show_summary = quanteda_options("print_dfm_summary"), 
+                   ...) {
+              if (show_summary) {
+                  docvars <- docvars(x)
                   cat("Document-feature matrix of: ",
                       format(ndoc(x), big.mark = ","), " document",
                       if (ndoc(x) > 1L || ndoc(x) == 0L) "s, " else ", ",
                       format(nfeat(x), big.mark=","), " feature",
                       if (nfeat(x) > 1L || nfeat(x) == 0L) "s" else "",
-                      if (is.resampled(x)) paste0(", ", nresample(x), " resamples") else "",
-                      if (prod(dim(x))) format_sparsity(sparsity(x)),
-                          # paste0(" (", format(sparsity(x)*100, digits = 3), "% sparse)"),
-                          # paste0(" (", format(sparsity(x)*100, digits = 6, nsmall = 2, scientific = 4), "% sparse)"),
-                      ".\n", sep = "")
+                      if (prod(dim(x))) format_sparsity(sparsity(x)), sep = "")
+                  if (ncol(docvars))
+                      cat(" and ", format(ncol(docvars), big.mark = ","), " docvar",
+                          if (ncol(docvars) == 1L) "" else "s", sep = "")
+                  cat(".\n")
               }
-              print_dfm(x, ndoc, nfeat, show.values, show.settings, ...)
+              print_dfm(x, max_ndoc, max_nfeat, ...)
           })
 
-#' @rdname print.dfm
-#' @param object the item to be printed
+#' @rdname print-quanteda
 setMethod("show", signature(object = "dfm"), function(object) print(object))
 
+# internal function for print.dfm
+print_dfm <- function(x, max_ndoc, max_nfeat, show_summary, ...) {
+    
+    unused_dots(...)
+    x <- as.dfm(x)
+    ndoc <- ndoc(x)
+    nfeat <- nfeat(x)
+    if (max_ndoc < 0 || max_ndoc > ndoc) 
+        max_ndoc <- ndoc
+    if (max_nfeat < 0 || max_nfeat > nfeat)
+        max_nfeat <- nfeat
+    
+    Matrix::printSpMatrix(x[seq_len(max_ndoc), seq_len(max_nfeat)], 
+                          col.names = TRUE, zero.print = 0)
+    ndoc_rem <- ndoc - max_ndoc
+    nfeat_rem <- nfeat - max_nfeat
+    if (ndoc_rem > 0 || nfeat_rem > 0) {
+        cat("[", sep = "") 
+        if (ndoc_rem > 0) {
+            cat(" reached max_ndoc ... ", format(ndoc_rem, big.mark = ","), " more document", sep = "") 
+            if (ndoc_rem > 1) cat("s", sep = "")
+        }
+        if (ndoc_rem > 0 && nfeat_rem > 0) 
+            cat(",", sep = "")
+        if (nfeat_rem > 0) {
+            cat(" reached max_nfeat ... ", format(nfeat_rem, big.mark = ","), " more feature", sep = "") 
+            if (nfeat_rem > 1) cat("s", sep = "")
+        }
+        cat(" ]\n", sep = "") 
+    }
+}
+
 
 #' format a sparsity value for printing
 #'
-#' Inputs a dfm sparsity value from \code{\link{sparsity}} and formats it for
-#' printing in \code{\link{print.dfm}}.
+#' Inputs a dfm sparsity value from [sparsity()] and formats it for
+#' printing in `print.dfm()`.
 #' @param x input sparsity value, ranging from 0 to 1.0
 #' @param threshold value below which the decimal places will be rounded and
 #'   printed with an inequality
-#' @param digits \code{digits} input to \code{\link{format}}
-#' @param nsmall \code{nsmall} input to \code{\link{format}}
-#' @return \code{character} value for inserting into the dfm print output
+#' @param digits `digits` input to [format()]
+#' @param nsmall `nsmall` input to [format()]
+#' @return `character` value for inserting into the dfm print output
 #' @examples 
 #' s <- c(.9, .99, .999, .9999, .99999, 
 #'        .1, .01, .001, .0001, .000001, .0000001, .00000001, .000000000001, 
@@ -90,45 +107,19 @@ format_sparsity <- function(x, threshold = .01, digits = 3, nsmall = 1) {
 }
 
 
-# internal function for print.dfm and print.fcm
-print_dfm <- function(x, ndoc, nfeat, show_values, show_settings, ...) {
-    
-    if (show_settings)
-        cat("Settings: TO BE IMPLEMENTED.")
-    if (!is.null(show_values)) {
-        # if show.values is set to TRUE, show full matrix
-        ndoc <- nrow(x)
-        nfeat <- ncol(x)
-    } else {  
-        if (nrow(x) <= ndoc && ncol(x) <= nfeat) {
-            # use TRUE default but limit dimensions
-            ndoc <- nrow(x)
-            nfeat <- ncol(x)
-            show_values <- TRUE
-        } else {
-            # turn off display if > dimensions
-            show_values <- FALSE        
-        }                      
-    }
-    if (show_values) {
-        Matrix::printSpMatrix2(x[seq_len(ndoc), seq_len(nfeat)], 
-                               col.names = TRUE, zero.print = 0, ...)
-    }
-}
-
 #' Return the first or last part of a dfm
 #' 
-#' For a \link{dfm} object, returns the first or last \code{n} documents 
-#' and first \code{nfeat} features.
+#' For a [dfm] object, returns the first or last `n` documents 
+#' and first `nfeat` features.
 #' @param x a dfm object
 #' @param n a single, positive integer.  If positive, size for the resulting
 #'   object: number of first/last documents for the dfm. If negative, all but
 #'   the n last/first number of documents of x.
 #' @param nf the number of features to return, where the resulting object 
-#'   will contain the first \code{ncol} features; default is all features
+#'   will contain the first `ncol` features; default is all features
 #' @param ... additional arguments passed to other functions
-#' @return A \link{dfm} class object corresponding to the subset defined 
-#'   by \code{n} and \code{nfeat}.
+#' @return A [dfm] class object corresponding to the subset defined 
+#'   by `n` and `nfeat`.
 #' @export
 #' @name head.dfm
 #' @method head dfm
