@@ -1,8 +1,11 @@
 
 subset_fcm <- function(x, i, j, ..., drop) {
     
-    attrs <- attributes(x)
+    if (missing(i) && missing(j)) return(x)
+    
+    slots <- get_fcm_slots(x)
     error <- FALSE
+    if (nargs() == 2) error <- TRUE
     if (!missing(i)) {
         if (is.character(i) && any(!i %in% rownames(x))) error <- TRUE
         if (is.numeric(i) && any(i > nrow(x))) error <- TRUE
@@ -13,21 +16,19 @@ subset_fcm <- function(x, i, j, ..., drop) {
     }
     if (error) stop("Subscript out of bounds")
     
-    if (missing(i) && missing(j)) {
-        return(x)
-    } else if (!missing(i) && missing(j)) {
+    if (!missing(i) && missing(j)) {
         x <- "["(as(x, "Matrix"), i, , ..., drop = FALSE)
     } else if (missing(i) && !missing(j)) {
         x <- "["(as(x, "Matrix"), , j, ..., drop = FALSE)
     } else {
         x <- "["(as(x, "Matrix"), i, j, ..., drop = FALSE)    
     }
-    matrix2fcm(x, attrs)
+    matrix2fcm(x, slots)
 }
 
 #' @param i index for features
 #' @param j index for features
-#' @param drop always set to \code{FALSE}
+#' @param drop always set to `FALSE`
 #' @param ... additional arguments not used here
 #' @rdname fcm-class
 #' @export
