@@ -8,13 +8,29 @@ Text keep_token(Text tokens,
           const std::vector<std::size_t> &spans,
           const SetNgrams &set_words,
           const bool &padding,
-          const std::pair<int, int> &window){
+          const std::pair<int, int> &window,
+          const std::pair<int, int> &pos){
     
     if (tokens.size() == 0) return {}; // return empty vector for empty text
     
     unsigned int filler = UINT_MAX; // use upper limit as a filler
     
     bool match = false;
+    std::size_t start, end;
+    if (pos.first == 0) {
+        start = 0;
+    } else if (pos.first > 0) {
+        start = std::min((int)tokens.size(), pos.first - 1);
+    } else {
+        start = std::max(0, (int)tokens.size() + pos.first);
+    }
+    if (pos.second == 0) {
+        end = 0;
+    } else if (pos.second > 0) {
+        end = std::min((int)tokens.size(), pos.second);
+    } else {
+        end = std::max(0, (int)tokens.size() + pos.second + 1);
+    }
     Text tokens_copy(tokens.size());
     if (padding) {
         std::fill(tokens_copy.begin(), tokens_copy.end(), 0);
@@ -23,7 +39,7 @@ Text keep_token(Text tokens,
     }
     for (std::size_t span : spans) { // substitution starts from the longest sequences
         if (tokens.size() < span) continue;
-        for (std::size_t i = 0; i < tokens.size() - (span - 1); i++) {
+        for (std::size_t i = start; i < end - (span - 1); i++) {
             Ngram ngram(tokens.begin() + i, tokens.begin() + i + span);
             auto it = set_words.find(ngram);
             if (it != set_words.end()) {
@@ -54,16 +70,32 @@ Text remove_token(Text tokens,
             const std::vector<std::size_t> &spans,
             const SetNgrams &set_words,
             const bool &padding,
-            const std::pair<int, int> &window){
+            const std::pair<int, int> &window,
+            const std::pair<int, int> &pos){
 
     if (tokens.size() == 0) return {}; // return empty vector for empty text
     
     unsigned int filler = UINT_MAX; // use upper limit as a filler
     Text tokens_copy = tokens;
     bool match = false;
+    std::size_t start, end;
+    if (pos.first == 0) {
+        start = 0;
+    } else if (pos.first > 0) {
+        start = std::min((int)tokens.size(), pos.first - 1);
+    } else {
+        start = std::max(0, (int)tokens.size() + pos.first);
+    }
+    if (pos.second == 0) {
+        end = 0;
+    } else if (pos.second > 0) {
+        end = std::min((int)tokens.size(), pos.second);
+    } else {
+        end = std::max(0, (int)tokens.size() + pos.second + 1);
+    }
     for (std::size_t span : spans) { // substitution starts from the longest sequences
         if (tokens.size() < span) continue;
-        for (std::size_t i = 0; i < tokens.size() - (span - 1); i++) {
+        for (std::size_t i = start; i < end - (span - 1); i++) {
             Ngram ngram(tokens.begin() + i, tokens.begin() + i + span);
             auto it = set_words.find(ngram);
             if (it != set_words.end()) {
@@ -100,22 +132,25 @@ struct select_mt : public Worker{
     const int &mode;
     const bool &padding;
     const std::pair<int, int> &window;
+    const std::pair<int, int> &pos;
     
     // Constructor
     select_mt(Texts &texts_, const std::vector<std::size_t> &spans_, 
-              const SetNgrams &set_words_, const int &mode_, const bool &padding_, const std::pair<int, int> &window_):
-              texts(texts_), spans(spans_), set_words(set_words_), mode(mode_), padding(padding_), window(window_){}
+              const SetNgrams &set_words_, const int &mode_, const bool &padding_, 
+              const std::pair<int, int> &window_, const std::pair<int, int> &pos_):
+              texts(texts_), spans(spans_), set_words(set_words_), mode(mode_), padding(padding_), 
+              window(window_), pos(pos_){}
     
     // parallelFor calles this function with std::size_t
     void operator()(std::size_t begin, std::size_t end){
         //Rcout << "Range " << begin << " " << end << "\n";
         if (mode == 1) {
             for (std::size_t h = begin; h < end; h++) {
-                texts[h] = keep_token(texts[h], spans, set_words, padding, window);
+                texts[h] = keep_token(texts[h], spans, set_words, padding, window, pos);
             }
-        } else if(mode == 2) {
+        } else if (mode == 2) {
             for (std::size_t h = begin; h < end; h++) {
-                texts[h] = remove_token(texts[h], spans, set_words, padding, window);
+                texts[h] = remove_token(texts[h], spans, set_words, padding, window, pos);
             }
         } else {
             for (std::size_t h = begin; h < end; h++) {
@@ -144,11 +179,14 @@ List qatd_cpp_tokens_select(const List &texts_,
                             int mode,
                             bool padding,
                             int window_left,
-                            int window_right){
+                            int window_right,
+                            int pos_from,
+                            int pos_to){
     
     Texts texts = Rcpp::as<Texts>(texts_);
     Types types = Rcpp::as<Types>(types_);
     std::pair<int, int> window(window_left, window_right);
+    std::pair<int, int> pos(pos_from, pos_to);
     
     SetNgrams set_words;
     std::vector<std::size_t> spans = register_ngrams(words_, set_words);
@@ -156,16 +194,16 @@ List qatd_cpp_tokens_select(const List &texts_,
     // dev::Timer timer;
     // dev::start_timer("Token select", timer);
 #if QUANTEDA_USE_TBB
-    select_mt select_mt(texts, spans, set_words, mode, padding, window);
+    select_mt select_mt(texts, spans, set_words, mode, padding, window, pos);
     parallelFor(0, texts.size(), select_mt);
 #else
     if (mode == 1) {
         for (std::size_t h = 0; h < texts.size(); h++) {
-            texts[h] = keep_token(texts[h], spans, set_words, padding, window);
+            texts[h] = keep_token(texts[h], spans, set_words, padding, window, pos);
         }
     } else if(mode == 2) {
         for (std::size_t h = 0; h < texts.size(); h++) {
-            texts[h] = remove_token(texts[h], spans, set_words, padding, window);
+            texts[h] = remove_token(texts[h], spans, set_words, padding, window, pos);
         }
     } else {
         for (std::size_t h = 0; h < texts.size(); h++){
@@ -184,11 +222,15 @@ toks <- list(rep(1:10, 1))
 dict <- list(c(1, 2), c(5, 6), 10, 15, 20)
 #dict <- list(c(99))
 #qatd_cpp_tokens_select(toks, letters, dict, 1, TRUE, 1, 1)
-qatd_cpp_tokens_select(toks, letters, dict, 1, TRUE, 0, 0)
-qatd_cpp_tokens_select(toks, letters, dict, 1, TRUE, 0, 1)
-qatd_cpp_tokens_select(toks, letters, dict, 1, TRUE, 0, 2)
-qatd_cpp_tokens_select(toks, letters, dict, 2, TRUE, 0, 0)
-qatd_cpp_tokens_select(toks, letters, dict, 2, TRUE, 0, 1)
-qatd_cpp_tokens_select(toks, letters, dict, 2, TRUE, 0, 2)
+qatd_cpp_tokens_select(toks, letters, dict, 1, TRUE, 0, 0, 1, 100)
+qatd_cpp_tokens_select(toks, letters, dict, 1, TRUE, 0, 1, 1, 100)
+qatd_cpp_tokens_select(toks, letters, dict, 1, FALSE, 0, 0, 1, 2)
+qatd_cpp_tokens_select(toks, letters, dict, 2, TRUE, 0, 0, 1, 5)
+qatd_cpp_tokens_select(toks, letters, dict, 2, TRUE, 0, 1, 1, 2)
+qatd_cpp_tokens_select(toks, letters, dict, 2, TRUE, 0, 2, 1, 3)
+qatd_cpp_tokens_select(toks, letters, as.list(1:10), 1, FALSE, 0, 0, 1, 2)
+qatd_cpp_tokens_select(toks, letters, as.list(1:10), 1, TRUE, 0, 0, 1, 2)
+qatd_cpp_tokens_select(toks, letters, as.list(1:10), 2, FALSE, 0, 0, 1, 1)
+qatd_cpp_tokens_select(toks, letters, as.list(1:10), 2, TRUE, 0, 0, 1, 1)
 
 */
