@@ -1,49 +1,50 @@
-context('Testing fcm*.R')
+context("testing fcm")
 
-# test_that("compare the output feature co-occurrence matrix to that of the text2vec package", {
-#     skip_if_not_installed("text2vec")
-#     library("text2vec")
-#     
-#     txt <- "A D A C E A D F E B A C E D"
-#     tokens <- txt %>% tolower %>% word_tokenizer
-#     it <- itoken(tokens)
-#     v <- create_vocabulary(it)
-#     vectorizer <- vocab_vectorizer(v)
-#     tcm <- create_tcm(itoken(tokens), vectorizer, skip_grams_window = 3L)
-#     
-#     # convert to a symmetric matrix to facilitate the sorting
-#     tcm <- as.matrix(tcm)
-#     ttcm <- tcm
-#     diag(ttcm) <- 0
-#     tcm <- tcm + t(ttcm)
-#     
-#     # sort the matrix according to rowname-colname and convert back to a upper triangle matrix
-#     tcm <- tcm[order(rownames(tcm)), order(colnames(tcm))]
-#     tcm[lower.tri(tcm, diag = FALSE)] <- 0
-#     
-#     toks <- tokens(char_tolower(txt), remove_punct = TRUE)
-#     fcm <- fcm(toks, context = "window", count = "weighted", window = 3)
-#     fcm <- fcm_sort(fcm)
-#     expect_true(all(round(fcm, 2) == round(tcm, 2)))
-#     
-# })
+test_that("compare the output feature co-occurrence matrix to that of the text2vec package", {
+    skip_if_not_installed("text2vec")
+    library("text2vec")
+
+    txt <- "A D A C E A D F E B A C E D"
+    tokens <- txt %>% tolower %>% word_tokenizer
+    it <- itoken(tokens)
+    v <- create_vocabulary(it)
+    vectorizer <- vocab_vectorizer(v)
+    tcm <- create_tcm(itoken(tokens), vectorizer, skip_grams_window = 3L)
+
+    # convert to a symmetric matrix to facilitate the sorting
+    tcm <- as.matrix(tcm)
+    ttcm <- tcm
+    # diag(ttcm) <- 0
+    tcm <- tcm + t(ttcm)
+
+    # sort the matrix according to rowname-colname and convert back to a upper triangle matrix
+    tcm <- tcm[order(rownames(tcm)), order(colnames(tcm))]
+    tcm[lower.tri(tcm, diag = FALSE)] <- 0
+
+    toks <- tokens(char_tolower(txt), remove_punct = TRUE)
+    fcm <- fcm(toks, context = "window", count = "weighted", weights = 1 / seq_len(3),
+               window = 3)
+    fcm <- fcm_sort(fcm)
+
+    expect_equivalent(as.matrix(fcm), tcm, tol = .00001)
+})
 
 test_that("fcm works with character and tokens in the same way", {
     txt <- "A D A C E A D F E B A C E D"
-    fcm_char <- fcm(txt, context = "window", count = "weighted", 
-                    weights = c(3, 2, 1), window = 3)           
+    fcmt_char <- fcm(txt, context = "window", count = "weighted",
+                    weights = c(3, 2, 1), window = 3)
     toks <- tokens(txt)
-    fcm_toks <- fcm(toks, context = "window", count = "weighted",  
-                    weights = c(3, 2, 1), window = 3) 
-    expect_equivalent(round(as.matrix(fcm_char), 2), 
-                      round(as.matrix(fcm_toks), 2))
+    fcmt_toks <- fcm(toks, context = "window", count = "weighted",
+                    weights = c(3, 2, 1), window = 3)
+    expect_equivalent(round(as.matrix(fcmt_char), 2),
+                      round(as.matrix(fcmt_toks), 2))
 })
 
 # Testing weighting function
 
-test_that("not weighted",{
+test_that("not weighted", {
     txt <- "A D A C E A D F E B A C E D"
-    fcm <- fcm(txt, context = "window", window = 3) 
+    fcmt <- fcm(txt, context = "window", window = 3)
 
     mat <- matrix(c(4, 1, 4, 4, 5, 2,
                      0, 0, 1, 1, 2, 1,
@@ -52,14 +53,14 @@ test_that("not weighted",{
                      0, 0, 0, 0, 0, 2,
                      0, 0, 0, 0, 0, 0),
                    nrow = 6, ncol = 6, byrow = TRUE)
-    fcm <- fcm_sort(fcm)
-    expect_equivalent(as.matrix(fcm), mat)
+    fcmt <- fcm_sort(fcmt)
+    expect_equivalent(as.matrix(fcmt), mat)
 })
 
-test_that("weighted by default",{
+test_that("weighted by default", {
     txt <- "A D A C E A D F E B A C E D"
-    fcm <- fcm(txt, context = "window", count = "weighted", window = 3)
-    
+    fcmt <- fcm(txt, context = "window", count = "weighted", window = 3)
+
     mat <- matrix(c(1.67, 1, 2.83, 3.33, 2.83, 0.83,
                      0, 0, 0.5, 0.33, 1.33, 0.50,
                      0, 0, 0, 1.33, 2.33, 0,
@@ -67,13 +68,13 @@ test_that("weighted by default",{
                      0, 0, 0, 0, 0, 1.33,
                      0, 0, 0, 0, 0, 0),
                    nrow = 6, ncol = 6, byrow = TRUE)
-    fcm <- fcm_sort(fcm)
-    expect_equivalent(mat, round(as.matrix(fcm), 2))
+    fcmt <- fcm_sort(fcmt)
+    expect_equivalent(mat, round(as.matrix(fcmt), 2))
 })
 
-test_that("customized weighting function",{
+test_that("customized weighting function", {
     txt <- "A D A C E A D F E B A C E D"
-    fcm <- fcm(txt, context = "window", count = "weighted", weights = c(3,2,1), window = 3)           
+    fcmt <- fcm(txt, context = "window", count = "weighted", weights = c(3, 2, 1), window = 3)
 
     mat <- matrix(c(6, 3, 9, 10, 10, 3,
                      0, 0, 2, 1, 4, 2,
@@ -82,8 +83,8 @@ test_that("customized weighting function",{
                      0, 0, 0, 0, 0, 4,
                      0, 0, 0, 0, 0, 0),
                    nrow = 6, ncol = 6, byrow = TRUE)
-    fcm <- fcm_sort(fcm)
-    expect_equivalent(mat, round(as.matrix(fcm), 2))
+    fcmt <- fcm_sort(fcmt)
+    expect_equivalent(mat, round(as.matrix(fcmt), 2))
 })
 
 test_that("ordered setting: window", {
@@ -99,8 +100,8 @@ test_that("ordered setting: window", {
                    nrow = 6, ncol = 6, byrow = TRUE)
     expect_true(all(round(fcmat, 2) == round(mat, 2)))
     expect_true(fcmat@ordered)
-    
-    fcmat_nord <- fcm(txt, context = "window", window = 3, ordered = FALSE, tri = FALSE) 
+
+    fcmat_nord <- fcm(txt, context = "window", window = 3, ordered = FALSE, tri = FALSE)
     fcmat_nord <- fcm_sort(fcmat_nord)
     mat <- matrix(c(4, 1, 4, 4, 5, 2,
                      1, 0, 1, 1, 2, 1,
@@ -113,9 +114,9 @@ test_that("ordered setting: window", {
     expect_false(fcmat_nord@ordered)
 })
 
-test_that("ordered setting: boolean",{
+test_that("ordered setting: boolean", {
     txt <- c("b a b c", "a a c b e", "a c e f g")
-    fcm <- fcm(txt, context = "window", count = "boolean", window = 2, 
+    fcm <- fcm(txt, context = "window", count = "boolean", window = 2,
                ordered = TRUE, tri = TRUE)
     fcm <- fcm_sort(fcm)
     mat <- matrix(c(1, 2, 3, 1, 0, 0,
@@ -126,8 +127,8 @@ test_that("ordered setting: boolean",{
                      0, 0, 0, 0, 0, 0),
                    nrow = 6, ncol = 6, byrow = TRUE)
     expect_equivalent(mat, as.matrix(fcm))
-    
-    fcm <- fcm(txt, context = "window", count = "boolean", window = 2, 
+
+    fcm <- fcm(txt, context = "window", count = "boolean", window = 2,
                ordered = FALSE, tri = TRUE)
     fcm <- fcm_sort(fcm)
     mat <- matrix(c(2, 2, 3, 1, 0, 0,
@@ -142,7 +143,7 @@ test_that("ordered setting: boolean",{
 
 test_that("window = 2", {
     txt <- c("a a a b b c", "a a c e", "a c e f g")
-    fcm <- fcm(txt, context = "window", count = "boolean", window = 2)           
+    fcm <- fcm(txt, context = "window", count = "boolean", window = 2)
     mat <- matrix(c(4, 1, 2, 2, 0, 0,
                    0, 2, 1, 0, 0, 0,
                    0, 0, 0, 2, 1, 0,
@@ -156,7 +157,7 @@ test_that("window = 2", {
 
 test_that("window = 3", {
     txt <- c("a a a b b c", "a a c e", "a c e f g")
-    fcm <- fcm(txt, context = "window", count = "boolean", window = 3)           
+    fcm <- fcm(txt, context = "window", count = "boolean", window = 3)
     fcm <- fcm_sort(fcm)
     mat <- matrix(c(4, 1, 3, 2, 1, 0,
                     0, 2, 1, 0, 0, 0,
@@ -172,8 +173,12 @@ test_that("fcm.dfm works same as fcm.tokens", {
     txt <- c("The quick brown fox jumped over the lazy dog.",
              "The dog jumped and ate the fox.")
     toks <- tokens(char_tolower(txt), remove_punct = TRUE)
+    dfmat <- dfm(toks)
     expect_equal(fcm(toks, context = "document"),
-                 fcm(dfm(toks), context = "document"))
+                 fcm(dfmat, context = "document"))
+    
+    fcmat <- fcm(dfm_weight(dfmat, scheme = "boolean"))
+    expect_equal(as.vector(fcmat[1, ]), c(0, 1, 1, 2, 2, 1, 1, 2, 1, 1))
 })
 
 test_that("fcm.dfm only works for context = \"document\"", {
@@ -184,7 +189,7 @@ test_that("fcm.dfm only works for context = \"document\"", {
                  "fcm.dfm only works on context = \"document\"")
 })
 
-test_that("fcm.dfm does works for context = \"document\" with weighed counts", {
+test_that("fcm.dfm does works for context = \"document\" with weighted counts", {
     txt <- c("The quick brown fox jumped over the lazy dog.",
              "The dog jumped and ate the fox.")
     toks <- tokens(char_tolower(txt), remove_punct = TRUE)
@@ -203,22 +208,45 @@ test_that("fcm works as expected for tokens_hashed", {
 })
 
 test_that("fcm print works as expected", {
-    txt <- c("a a a b b c", "a a c e", "a c e f g")
-    testfcm <- fcm(txt, context = "document", count = "frequency", tri = TRUE) 
-    expect_output(print(testfcm),
-                  "^Feature co-occurrence matrix of: 6 by 6 features.")
-    expect_output(print(testfcm[1:5, 1:5]),
-                  "^Feature co-occurrence matrix of: 5 by 5 features.")
-    expect_output(print(testfcm, show.settings = TRUE),
-                  "Settings: TO BE IMPLEMENTED")
-    expect_output(show(testfcm),
-                  "^Feature co-occurrence matrix of: 6 by 6 features.")
+    dfmt <- dfm(data_corpus_irishbudget2010[1:2],
+                remove_punct = FALSE, remove_numbers = FALSE, split_hyphens = TRUE)
+    fcmt <- fcm(dfmt)
+    expect_output(print(fcmt, max_nfeat = 6, show_summary = TRUE),
+                  paste0("^Feature co-occurrence matrix of: 2,251 by 2,251 features\\.",
+                         ".*",
+                         "\\[ reached max_feat \\.\\.\\. 2,245 more features, reached max_nfeat \\.\\.\\. 2,245 more features \\]$")
+    )
+    expect_output(print(fcmt[1:5, 1:5], max_nfeat = 6, show_summary = TRUE),
+                  paste0("^Feature co-occurrence matrix of: 5 by 5 features\\.",
+                         ".*",
+                         "supplementary\\s+0\\s+0\\s+0\\s+0\\s+21$")
+    )
+    expect_output(print(fcmt[1:10, 1:2], max_nfeat = 6, show_summary = TRUE),
+                  paste0("^Feature co-occurrence matrix of: 10 by 2 features\\.",
+                         ".*",
+                         "\\[ reached max_feat \\.\\.\\. 4 more features \\]$")
+    )
+    expect_output(print(fcmt[1:5, 1:5], max_nfeat = -1, show_summary = TRUE),
+                  paste0("^Feature co-occurrence matrix of: 5 by 5 features\\.",
+                         ".*",
+                         "supplementary\\s+0\\s+0\\s+0\\s+0\\s+21$")
+    )
+    expect_output(print(fcmt[1:10, 1:2], max_nfeat = -1, show_summary = TRUE),
+                  paste0("^Feature co-occurrence matrix of: 10 by 2 features\\.",
+                         ".*",
+                         "last\\s+0\\s+0$")
+    )
+    expect_output(print(fcmt, max_nfeat = 6, show_summary = FALSE),
+                  paste0("^\\s+features",
+                         ".*",
+                         "\\[ reached max_feat \\.\\.\\. 2,245 more features, reached max_nfeat \\.\\.\\. 2,245 more features \\]$")
+    )
 })
 
 test_that("fcm works the same for different object types", {
     txt <- c("a a a b b c", "a a c e", "a c e f g")
-    expect_identical(fcm(txt), fcm(corpus(txt)))
-    expect_identical(fcm(tokens(txt)), fcm(corpus(txt)))
+    expect_equivalent(fcm(txt), fcm(corpus(txt)))
+    expect_equivalent(fcm(tokens(txt)), fcm(corpus(txt)))
     expect_identical(fcm(txt), fcm(tokens(txt)))
 })
 
@@ -228,10 +256,10 @@ test_that("fcm expects error for wrong weight or window", {
     expect_error(fcm(toks, context = "window", window = 0),
                 "window size must be at least 1")
     expect_error(fcm(toks, context = "window", window = 2, weight = 0.1,
-                     count = "weighted", weights = c(1,2,3)),
+                     count = "weighted", weights = c(1, 2, 3)),
                  "weights length must be equal to the window size")
     expect_error(fcm(toks, context = "window", window = 2, weight = c(0.1, 0.2, 0.3),
-                     count = "weighted", weights = c(1,2,3)),
+                     count = "weighted", weights = c(1, 2, 3)),
                  "weights length must be equal to the window size")
 })
 
@@ -242,7 +270,7 @@ test_that("fcm works tokens with paddings, #788", {
     toks <- tokens(txt, remove_punct = TRUE)
     toks <- tokens_remove(toks, pattern = stopwords(), padding = TRUE)
     testfcm <- fcm(toks, context = "window", window = 3)
-    expect_equal(sort(colnames(testfcm)), sort(attr(toks, 'types')))
+    expect_equal(sort(colnames(testfcm)), sort(attr(toks, "types")))
 })
 
 test_that("as.network.fcm works", {
@@ -289,18 +317,18 @@ test_that("as.igraph.fcm works with window", {
 })
 
 test_that("test empty object is handled properly", {
-    
+
     mat <- quanteda:::make_null_dfm()
     expect_equal(dim(fcm(mat)), c(0, 0))
     expect_true(is.fcm(fcm(mat)))
-    
-    toks <- tokens(c('', ''))
+
+    toks <- tokens(c("", ""))
     expect_equal(dim(fcm(toks)), c(0, 0))
     expect_true(is.fcm(fcm(toks)))
 })
 
 test_that("arithmetic/linear operation works with dfm", {
-    
+
     mt <- fcm(dfm(c(d1 = "a a b", d2 = "a b b c", d3 = "c c d")))
     expect_true(is.fcm(mt + 2))
     expect_true(is.fcm(mt - 2))
@@ -314,7 +342,7 @@ test_that("arithmetic/linear operation works with dfm", {
     expect_true(is.fcm(2 ^ mt))
     expect_true(is.fcm(t(mt)))
     expect_equal(rowSums(mt), colSums(t(mt)))
-    
+
 })
 
 test_that("ordered is working correctly (#1413)", {
@@ -322,7 +350,7 @@ test_that("ordered is working correctly (#1413)", {
         as.matrix(fcm(c("a b c", "a b c"), "window", window = 1, ordered = TRUE)),
         matrix(c(0, 2, 0, 0, 0, 2, 0, 0, 0),
                nrow = 3, ncol = 3, byrow = TRUE))
-    
+
     expect_equivalent(
         as.matrix(fcm(c("a b c", "a b c"), "window", window = 2, ordered = TRUE)),
         matrix(c(0, 2, 2, 0, 0, 2, 0, 0, 0),
@@ -332,33 +360,33 @@ test_that("ordered is working correctly (#1413)", {
         as.matrix(fcm(c("a b c", "c b a"), "window", window = 1, ordered = TRUE)),
         matrix(c(0, 1, 0, 1, 0, 1, 0, 1, 0),
                nrow = 3, ncol = 3, byrow = TRUE))
-    
+
     expect_equivalent(
         as.matrix(fcm(c("a b c", "c b a"), "window", window = 2, ordered = TRUE)),
         matrix(c(0, 1, 1, 1, 0, 1, 1, 1, 0),
                nrow = 3, ncol = 3, byrow = TRUE))
-    
+
     expect_equal(fcm(c("a b c", "a b c"), "window", window = 1, ordered = TRUE, tri = TRUE),
                  fcm(c("a b c", "a b c"), "window", window = 1, ordered = TRUE, tri = FALSE))
-    
+
 })
 
 
 test_that("dimnames are always character vectors", {
     mt <- fcm(c("a b c", "a b c"), "window", window = 1, ordered = TRUE)
-    expect_identical(dimnames(mt[,character()]),
+    expect_identical(dimnames(mt[, character()]),
                      list(features = rownames(mt), features = character()))
-    expect_identical(dimnames(mt[,FALSE]),
+    expect_identical(dimnames(mt[, FALSE]),
                      list(features = rownames(mt), features = character()))
-    expect_identical(dimnames(mt[character(),]),
+    expect_identical(dimnames(mt[character(), ]),
                      list(features = character(), features = colnames(mt)))
-    expect_identical(dimnames(mt[FALSE,]),
+    expect_identical(dimnames(mt[FALSE, ]),
                      list(features = character(), features = colnames(mt)))
 })
 
 test_that("fcm_setnames works", {
     x <- fcm(c("a b c", "a b c"), "window", window = 1)
-    
+
     quanteda:::set_fcm_featnames(x) <- paste0("feature", 1:3)
     expect_identical(featnames(x), c("feature1", "feature2", "feature3"))
 
@@ -370,13 +398,35 @@ test_that("fcm feature names have encoding", {
     mt <- fcm(c("文書１" = "あ い い う", "文書２" = "え え え お"))
     expect_true(all(Encoding(colnames(mt)) == "UTF-8"))
     expect_true(all(Encoding(rownames(mt)) == "UTF-8"))
-    
+
     mt1 <- fcm_sort(mt)
     expect_true(all(Encoding(colnames(mt1)) == "UTF-8"))
     expect_true(all(Encoding(rownames(mt1)) == "UTF-8"))
-    
+
     mt2 <- fcm_remove(mt, c("あ"))
     expect_true(all(Encoding(colnames(mt2)) == "UTF-8"))
     expect_true(all(Encoding(rownames(mt2)) == "UTF-8"))
 })
 
+test_that("fcm raise nicer error message, #1267", {
+
+    txt <- c(d1 = "one two three", d2 = "two three four", d3 = "one three four")
+    mx <- fcm(dfm(txt))
+    expect_silent(mx[])
+    expect_error(mx["five"], "Subscript out of bounds")
+    expect_error(mx[, "five"], "Subscript out of bounds")
+    expect_error(mx[5], "Subscript out of bounds")
+    expect_error(mx[, 5], "Subscript out of bounds")
+    expect_error(mx[, 1:5], "Subscript out of bounds")
+    expect_error(mx["d4", "five"], "Subscript out of bounds")
+    expect_error(mx[, "five", TRUE], "Subscript out of bounds")
+    expect_error(mx[, 5, TRUE], "Subscript out of bounds")
+    expect_error(mx[, 1:5, TRUE], "Subscript out of bounds")
+    expect_error(mx["d4", "five", TRUE], "Subscript out of bounds")
+
+    expect_error(mx[4, 5], "Subscript out of bounds")
+    expect_error(mx[4:5], "Subscript out of bounds")
+    expect_error(mx[1:4, 1:5], "Subscript out of bounds")
+    expect_error(mx[4, 5, TRUE], "Subscript out of bounds")
+    expect_error(mx[1:4, 1:5, TRUE], "Subscript out of bounds")
+})
